Scitacean
=========

Scitacean is a high level Python package for downloading and uploading datasets from and to `SciCat <https://scicatproject.github.io/>`_.

To get started, read the `User Guide <./user-guide/index.rst>`_.

.. toctree::
   :hidden:

   user-guide/index
   reference/index
   developer/index
   release-notes
